pub struct DueNowResult {
pub deadlines: Vec<Deadline>,
pub has_more: bool,
}Expand description
Result of a DeadlineStore::due_now poll.
When has_more is true, the store has additional expired deadlines beyond
the returned deadlines. The scheduler should drain in a loop until
has_more is false to avoid leaving unfired deadlines in the store.
let store = InMemoryDeadlineStore::new();
loop {
let result = store.due_now(50).await.unwrap();
for deadline in result.deadlines {
// dispatch TimeoutDeadline command …
store.cancel(deadline.deadline_id()).await.unwrap();
}
if !result.has_more { break; }
}Fields
deadlines: Vec<Deadline>Expired deadlines, ordered soonest-first.
has_more: booltrue when the store contains more expired deadlines beyond deadlines.